@@ -10,14 +10,14 @@ import (
 	"strings"
 
 	"net/http"
-	_ "net/http/pprof" // load profiling http handler
+	"net/http/pprof"
 
 	log "github.com/sirupsen/logrus"
 
 	"github.com/dundee/gdu/v5/build"
 	"github.com/dundee/gdu/v5/internal/common"
-	"github.com/dundee/gdu/v5/pkg/analyze"
 	"github.com/dundee/gdu/v5/pkg/device"
+	gfs "github.com/dundee/gdu/v5/pkg/fs"
 	"github.com/dundee/gdu/v5/report"
 	"github.com/dundee/gdu/v5/stdout"
 	"github.com/dundee/gdu/v5/tui"
@@ -28,7 +28,7 @@ import (
 // UI is common interface for both terminal UI and text output
 type UI interface {
 	ListDevices(getter device.DevicesInfoGetter) error
-	AnalyzePath(path string, parentDir *analyze.Dir) error
+	AnalyzePath(path string, parentDir gfs.Item) error
 	ReadAnalysis(input io.Reader) error
 	SetIgnoreDirPaths(paths []string)
 	SetIgnoreDirPatterns(paths []string) error
@@ -48,6 +48,7 @@ type Flags struct {
 	MaxCores          int
 	ShowDisks         bool
 	ShowApparentSize  bool
+	ShowRelativeSize  bool
 	ShowVersion       bool
 	NoColor           bool
 	NonInteractive    bool
@@ -55,8 +56,9 @@ type Flags struct {
 	NoCross           bool
 	NoHidden          bool
 	Profiling         bool
-	EnableGC          bool
+	ConstGC           bool
 	Summarize         bool
+	UseSIPrefix       bool
 }
 
 // App defines the main application
@@ -71,6 +73,10 @@ type App struct {
 	PathChecker func(string) (fs.FileInfo, error)
 }
 
+func init() {
+	http.DefaultServeMux = http.NewServeMux()
+}
+
 // Run starts gdu main logic
 func (a *App) Run() (err error) {
 	var (
@@ -177,7 +183,8 @@ func (a *App) createUI() (UI, error) {
 			output,
 			!a.Flags.NoColor && a.Istty,
 			!a.Flags.NoProgress && a.Istty,
-			a.Flags.EnableGC,
+			a.Flags.ConstGC,
+			a.Flags.UseSIPrefix,
 		)
 		return ui, nil
 	}
@@ -188,8 +195,10 @@ func (a *App) createUI() (UI, error) {
 			!a.Flags.NoColor && a.Istty,
 			!a.Flags.NoProgress && a.Istty,
 			a.Flags.ShowApparentSize,
+			a.Flags.ShowRelativeSize,
 			a.Flags.Summarize,
-			a.Flags.EnableGC,
+			a.Flags.ConstGC,
+			a.Flags.UseSIPrefix,
 		)
 	} else {
 		ui = tui.CreateUI(
@@ -198,7 +207,9 @@ func (a *App) createUI() (UI, error) {
 			os.Stdout,
 			!a.Flags.NoColor,
 			a.Flags.ShowApparentSize,
-			a.Flags.EnableGC,
+			a.Flags.ShowRelativeSize,
+			a.Flags.ConstGC,
+			a.Flags.UseSIPrefix,
 		)
 
 		if !a.Flags.NoColor {
@@ -225,6 +236,11 @@ func (a *App) setNoCross(path string) error {
 func (a *App) runAction(ui UI, path string) error {
 	if a.Flags.Profiling {
 		go func() {
+			http.HandleFunc("/debug/pprof/", pprof.Index)
+			http.HandleFunc("/debug/pprof/cmdline", pprof.Cmdline)
+			http.HandleFunc("/debug/pprof/profile", pprof.Profile)
+			http.HandleFunc("/debug/pprof/symbol", pprof.Symbol)
+			http.HandleFunc("/debug/pprof/trace", pprof.Trace)
 			log.Println(http.ListenAndServe("localhost:6060", nil))
 		}()
 	}
