@@ -14,7 +14,7 @@ type ShouldDirBeIgnored func(name, path string) bool
 
 // Analyzer is type for dir analyzing function
 type Analyzer interface {
-	AnalyzeDir(path string, ignore ShouldDirBeIgnored, enableGC bool) fs.Item
+	AnalyzeDir(path string, ignore ShouldDirBeIgnored, constGC bool) fs.Item
 	GetProgressChan() chan CurrentProgress
 	GetDoneChan() chan struct{}
 	ResetProgress()
