@@ -3,38 +3,41 @@ package common
 import (
 	"regexp"
 	"strconv"
-
-	"github.com/dundee/gdu/v5/pkg/analyze"
 )
 
 // UI struct
 type UI struct {
-	Analyzer              analyze.Analyzer
+	Analyzer              Analyzer
 	IgnoreDirPaths        map[string]struct{}
 	IgnoreDirPathPatterns *regexp.Regexp
 	IgnoreHidden          bool
 	UseColors             bool
+	UseSIPrefix           bool
 	ShowProgress          bool
 	ShowApparentSize      bool
-	EnableGC              bool
+	ShowRelativeSize      bool
+	ConstGC               bool
 }
 
-// file size constants
+// binary multiplies prefixes (IEC)
 const (
 	_          = iota
-	KB float64 = 1 << (10 * iota)
-	MB
-	GB
-	TB
-	PB
-	EB
+	Ki float64 = 1 << (10 * iota)
+	Mi
+	Gi
+	Ti
+	Pi
+	Ei
 )
 
-// file count constants
+// SI prefixes
 const (
-	K int = 1e3
-	M int = 1e6
-	G int = 1e9
+	K int64 = 1e3
+	M int64 = 1e6
+	G int64 = 1e9
+	T int64 = 1e12
+	P int64 = 1e15
+	E int64 = 1e18
 )
 
 // FormatNumber returns number as a string with thousands separator
