@@ -6,7 +6,6 @@ import (
 	"fmt"
 	"io"
 	"os"
-	"runtime/debug"
 	"sort"
 	"strconv"
 	"sync"
@@ -16,6 +15,7 @@ import (
 	"github.com/dundee/gdu/v5/internal/common"
 	"github.com/dundee/gdu/v5/pkg/analyze"
 	"github.com/dundee/gdu/v5/pkg/device"
+	"github.com/dundee/gdu/v5/pkg/fs"
 	"github.com/fatih/color"
 )
 
@@ -30,12 +30,20 @@ type UI struct {
 }
 
 // CreateExportUI creates UI for stdout
-func CreateExportUI(output io.Writer, exportOutput io.Writer, useColors bool, showProgress bool, enableGC bool) *UI {
+func CreateExportUI(
+	output io.Writer,
+	exportOutput io.Writer,
+	useColors bool,
+	showProgress bool,
+	constGC bool,
+	useSIPrefix bool,
+) *UI {
 	ui := &UI{
 		UI: &common.UI{
 			ShowProgress: showProgress,
 			Analyzer:     analyze.CreateAnalyzer(),
-			EnableGC:     enableGC,
+			ConstGC:      constGC,
+			UseSIPrefix:  useSIPrefix,
 		},
 		output:       output,
 		exportOutput: exportOutput,
@@ -67,9 +75,9 @@ func (ui *UI) ReadAnalysis(input io.Reader) error {
 }
 
 // AnalyzePath analyzes recursively disk usage in given path
-func (ui *UI) AnalyzePath(path string, _ *analyze.Dir) error {
+func (ui *UI) AnalyzePath(path string, _ fs.Item) error {
 	var (
-		dir         *analyze.Dir
+		dir         fs.Item
 		wait        sync.WaitGroup
 		waitWritten sync.WaitGroup
 		err         error
@@ -86,16 +94,13 @@ func (ui *UI) AnalyzePath(path string, _ *analyze.Dir) error {
 	wait.Add(1)
 	go func() {
 		defer wait.Done()
-		if !ui.EnableGC {
-			defer debug.SetGCPercent(debug.SetGCPercent(-1))
-		}
-		dir = ui.Analyzer.AnalyzeDir(path, ui.CreateIgnoreFunc())
-		dir.UpdateStats(make(analyze.HardLinkedItems, 10))
+		dir = ui.Analyzer.AnalyzeDir(path, ui.CreateIgnoreFunc(), ui.ConstGC)
+		dir.UpdateStats(make(fs.HardLinkedItems, 10))
 	}()
 
 	wait.Wait()
 
-	sort.Sort(dir.Files)
+	sort.Sort(dir.GetFiles())
 
 	var buff bytes.Buffer
 
@@ -144,7 +149,7 @@ func (ui *UI) updateProgress() {
 	progressChan := ui.Analyzer.GetProgressChan()
 	doneChan := ui.Analyzer.GetDoneChan()
 
-	var progress analyze.CurrentProgress
+	var progress common.CurrentProgress
 
 	i := 0
 	for {
@@ -179,21 +184,49 @@ func (ui *UI) updateProgress() {
 }
 
 func (ui *UI) formatSize(size int64) string {
+	if ui.UseSIPrefix {
+		return ui.formatWithDecPrefix(size)
+	}
+	return ui.formatWithBinPrefix(size)
+}
+
+func (ui *UI) formatWithBinPrefix(size int64) string {
 	fsize := float64(size)
 
 	switch {
-	case fsize >= common.EB:
-		return ui.orange.Sprintf("%.1f", fsize/common.EB) + " EiB"
-	case fsize >= common.PB:
-		return ui.orange.Sprintf("%.1f", fsize/common.PB) + " PiB"
-	case fsize >= common.TB:
-		return ui.orange.Sprintf("%.1f", fsize/common.TB) + " TiB"
-	case fsize >= common.GB:
-		return ui.orange.Sprintf("%.1f", fsize/common.GB) + " GiB"
-	case fsize >= common.MB:
-		return ui.orange.Sprintf("%.1f", fsize/common.MB) + " MiB"
-	case fsize >= common.KB:
-		return ui.orange.Sprintf("%.1f", fsize/common.KB) + " KiB"
+	case fsize >= common.Ei:
+		return ui.orange.Sprintf("%.1f", fsize/common.Ei) + " EiB"
+	case fsize >= common.Pi:
+		return ui.orange.Sprintf("%.1f", fsize/common.Pi) + " PiB"
+	case fsize >= common.Ti:
+		return ui.orange.Sprintf("%.1f", fsize/common.Ti) + " TiB"
+	case fsize >= common.Gi:
+		return ui.orange.Sprintf("%.1f", fsize/common.Gi) + " GiB"
+	case fsize >= common.Mi:
+		return ui.orange.Sprintf("%.1f", fsize/common.Mi) + " MiB"
+	case fsize >= common.Ki:
+		return ui.orange.Sprintf("%.1f", fsize/common.Ki) + " KiB"
+	default:
+		return ui.orange.Sprintf("%d", size) + " B"
+	}
+}
+
+func (ui *UI) formatWithDecPrefix(size int64) string {
+	fsize := float64(size)
+
+	switch {
+	case size >= common.E:
+		return ui.orange.Sprintf("%.1f", fsize/float64(common.E)) + " EB"
+	case size >= common.P:
+		return ui.orange.Sprintf("%.1f", fsize/float64(common.P)) + " PB"
+	case size >= common.T:
+		return ui.orange.Sprintf("%.1f", fsize/float64(common.T)) + " TB"
+	case size >= common.G:
+		return ui.orange.Sprintf("%.1f", fsize/float64(common.G)) + " GB"
+	case size >= common.M:
+		return ui.orange.Sprintf("%.1f", fsize/float64(common.M)) + " MB"
+	case size >= common.K:
+		return ui.orange.Sprintf("%.1f", fsize/float64(common.K)) + " kB"
 	default:
 		return ui.orange.Sprintf("%d", size) + " B"
 	}
