@@ -5,7 +5,6 @@ import (
 	"io"
 	"math"
 	"runtime"
-	"runtime/debug"
 	"sort"
 	"sync"
 	"time"
@@ -13,6 +12,7 @@ import (
 	"github.com/dundee/gdu/v5/internal/common"
 	"github.com/dundee/gdu/v5/pkg/analyze"
 	"github.com/dundee/gdu/v5/pkg/device"
+	"github.com/dundee/gdu/v5/pkg/fs"
 	"github.com/dundee/gdu/v5/report"
 	"github.com/fatih/color"
 )
@@ -35,16 +35,20 @@ func CreateStdoutUI(
 	useColors bool,
 	showProgress bool,
 	showApparentSize bool,
+	showRelativeSize bool,
 	summarize bool,
-	enableGC bool,
+	constGC bool,
+	useSIPrefix bool,
 ) *UI {
 	ui := &UI{
 		UI: &common.UI{
 			UseColors:        useColors,
 			ShowProgress:     showProgress,
 			ShowApparentSize: showApparentSize,
+			ShowRelativeSize: showRelativeSize,
 			Analyzer:         analyze.CreateAnalyzer(),
-			EnableGC:         enableGC,
+			ConstGC:          constGC,
+			UseSIPrefix:      useSIPrefix,
 		},
 		output:    output,
 		summarize: summarize,
@@ -125,9 +129,9 @@ func (ui *UI) ListDevices(getter device.DevicesInfoGetter) error {
 }
 
 // AnalyzePath analyzes recursively disk usage in given path
-func (ui *UI) AnalyzePath(path string, _ *analyze.Dir) error {
+func (ui *UI) AnalyzePath(path string, _ fs.Item) error {
 	var (
-		dir  *analyze.Dir
+		dir  fs.Item
 		wait sync.WaitGroup
 	)
 
@@ -142,11 +146,8 @@ func (ui *UI) AnalyzePath(path string, _ *analyze.Dir) error {
 	wait.Add(1)
 	go func() {
 		defer wait.Done()
-		if !ui.EnableGC {
-			defer debug.SetGCPercent(debug.SetGCPercent(-1))
-		}
-		dir = ui.Analyzer.AnalyzeDir(path, ui.CreateIgnoreFunc())
-		dir.UpdateStats(make(analyze.HardLinkedItems, 10))
+		dir = ui.Analyzer.AnalyzeDir(path, ui.CreateIgnoreFunc(), ui.ConstGC)
+		dir.UpdateStats(make(fs.HardLinkedItems, 10))
 	}()
 
 	wait.Wait()
@@ -160,15 +161,15 @@ func (ui *UI) AnalyzePath(path string, _ *analyze.Dir) error {
 	return nil
 }
 
-func (ui *UI) showDir(dir *analyze.Dir) {
-	sort.Sort(dir.Files)
+func (ui *UI) showDir(dir fs.Item) {
+	sort.Sort(dir.GetFiles())
 
-	for _, file := range dir.Files {
+	for _, file := range dir.GetFiles() {
 		ui.printItem(file)
 	}
 }
 
-func (ui *UI) printTotalItem(file analyze.Item) {
+func (ui *UI) printTotalItem(file fs.Item) {
 	var lineFormat string
 	if ui.UseColors {
 		lineFormat = "%20s %s\n"
@@ -191,7 +192,7 @@ func (ui *UI) printTotalItem(file analyze.Item) {
 	)
 }
 
-func (ui *UI) printItem(file analyze.Item) {
+func (ui *UI) printItem(file fs.Item) {
 	var lineFormat string
 	if ui.UseColors {
 		lineFormat = "%s %20s %s\n"
@@ -251,7 +252,7 @@ func (ui *UI) ReadAnalysis(input io.Reader) error {
 		}
 		runtime.GC()
 
-		dir.UpdateStats(make(analyze.HardLinkedItems, 10))
+		dir.UpdateStats(make(fs.HardLinkedItems, 10))
 
 		if ui.ShowProgress {
 			doneChan <- struct{}{}
@@ -304,7 +305,7 @@ func (ui *UI) updateProgress() {
 	progressChan := ui.Analyzer.GetProgressChan()
 	doneChan := ui.Analyzer.GetDoneChan()
 
-	var progress analyze.CurrentProgress
+	var progress common.CurrentProgress
 
 	i := 0
 	for {
@@ -331,21 +332,49 @@ func (ui *UI) updateProgress() {
 }
 
 func (ui *UI) formatSize(size int64) string {
+	if ui.UseSIPrefix {
+		return ui.formatWithDecPrefix(size)
+	}
+	return ui.formatWithBinPrefix(size)
+}
+
+func (ui *UI) formatWithBinPrefix(size int64) string {
 	fsize := float64(size)
 
 	switch {
-	case fsize >= common.EB:
-		return ui.orange.Sprintf("%.1f", fsize/common.EB) + " EiB"
-	case fsize >= common.PB:
-		return ui.orange.Sprintf("%.1f", fsize/common.PB) + " PiB"
-	case fsize >= common.TB:
-		return ui.orange.Sprintf("%.1f", fsize/common.TB) + " TiB"
-	case fsize >= common.GB:
-		return ui.orange.Sprintf("%.1f", fsize/common.GB) + " GiB"
-	case fsize >= common.MB:
-		return ui.orange.Sprintf("%.1f", fsize/common.MB) + " MiB"
-	case fsize >= common.KB:
-		return ui.orange.Sprintf("%.1f", fsize/common.KB) + " KiB"
+	case fsize >= common.Ei:
+		return ui.orange.Sprintf("%.1f", fsize/common.Ei) + " EiB"
+	case fsize >= common.Pi:
+		return ui.orange.Sprintf("%.1f", fsize/common.Pi) + " PiB"
+	case fsize >= common.Ti:
+		return ui.orange.Sprintf("%.1f", fsize/common.Ti) + " TiB"
+	case fsize >= common.Gi:
+		return ui.orange.Sprintf("%.1f", fsize/common.Gi) + " GiB"
+	case fsize >= common.Mi:
+		return ui.orange.Sprintf("%.1f", fsize/common.Mi) + " MiB"
+	case fsize >= common.Ki:
+		return ui.orange.Sprintf("%.1f", fsize/common.Ki) + " KiB"
+	default:
+		return ui.orange.Sprintf("%d", size) + " B"
+	}
+}
+
+func (ui *UI) formatWithDecPrefix(size int64) string {
+	fsize := float64(size)
+
+	switch {
+	case size >= common.E:
+		return ui.orange.Sprintf("%.1f", fsize/float64(common.E)) + " EB"
+	case size >= common.P:
+		return ui.orange.Sprintf("%.1f", fsize/float64(common.P)) + " PB"
+	case size >= common.T:
+		return ui.orange.Sprintf("%.1f", fsize/float64(common.T)) + " TB"
+	case size >= common.G:
+		return ui.orange.Sprintf("%.1f", fsize/float64(common.G)) + " GB"
+	case size >= common.M:
+		return ui.orange.Sprintf("%.1f", fsize/float64(common.M)) + " MB"
+	case size >= common.K:
+		return ui.orange.Sprintf("%.1f", fsize/float64(common.K)) + " kB"
 	default:
 		return ui.orange.Sprintf("%d", size) + " B"
 	}
